RecordResponse class

Constructors

RecordResponse({bool? success, String? path, String? msg, String? key, double? audioTimeLength})

Properties

audioTimeLength ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
msg ↔ String?
getter/setter pair
path ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited